## Introduction
This library help to preprocessing Vietnamese text
### How to use
```
from flashtext import KeywordProcessor
from vn_helper import text_preprocessing, num_preprocessing
text = "text"
new_text = text_preprocessing(text)
new_text = text_preprocessing(text)
```
